summaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
authornjl <njl@FreeBSD.org>2003-11-15 18:58:29 +0000
committernjl <njl@FreeBSD.org>2003-11-15 18:58:29 +0000
commit1f1358c8e0b607c2fdaf5da2deda6bbfb118ef8c (patch)
tree855bd7788b85fd9a5e6bfd56b190cddac1fb387d
parent06ab707e796698baced2d1cb5ff031286e34e4cd (diff)
downloadFreeBSD-src-1f1358c8e0b607c2fdaf5da2deda6bbfb118ef8c.zip
FreeBSD-src-1f1358c8e0b607c2fdaf5da2deda6bbfb118ef8c.tar.gz
Add the pc_acpi_id PCPU member. The new acpi_cpu driver uses this to
dereference the softc.
-rw-r--r--sys/amd64/amd64/machdep.c2
-rw-r--r--sys/amd64/include/pcpu.h3
-rw-r--r--sys/ia64/ia64/machdep.c1
-rw-r--r--sys/ia64/include/pcpu.h3
4 files changed, 7 insertions, 2 deletions
diff --git a/sys/amd64/amd64/machdep.c b/sys/amd64/amd64/machdep.c
index 5e6254d..e32d82a 100644
--- a/sys/amd64/amd64/machdep.c
+++ b/sys/amd64/amd64/machdep.c
@@ -1279,6 +1279,8 @@ hammer_time(u_int64_t modulep, u_int64_t physfree)
void
cpu_pcpu_init(struct pcpu *pcpu, int cpuid, size_t size)
{
+
+ pcpu->pc_acpi_id = 0xffffffff;
}
int
diff --git a/sys/ia64/ia64/machdep.c b/sys/ia64/ia64/machdep.c
index 2724b44..5490e5c 100644
--- a/sys/ia64/ia64/machdep.c
+++ b/sys/ia64/ia64/machdep.c
@@ -361,6 +361,7 @@ cpu_pcpu_init(struct pcpu *pcpu, int cpuid, size_t size)
KASSERT(size >= pcpusz + sizeof(struct pcb),
("%s: too small an allocation for pcpu", __func__));
pcpu->pc_pcb = (struct pcb *)((char*)pcpu + pcpusz);
+ pcpu->pc_acpi_id = 0xffffffff;
}
void
diff --git a/sys/ia64/include/pcpu.h b/sys/ia64/include/pcpu.h
index 38475fb..12f36c8 100644
--- a/sys/ia64/include/pcpu.h
+++ b/sys/ia64/include/pcpu.h
@@ -38,7 +38,8 @@
uint64_t pc_lid; /* local CPU ID */ \
uint32_t pc_awake:1; /* CPU is awake? */ \
uint64_t pc_clock; /* Clock counter. */ \
- uint64_t pc_clockadj; /* Clock adjust. */
+ uint64_t pc_clockadj; /* Clock adjust. */ \
+ uint32_t pc_acpi_id; /* ACPI CPU id. */
struct pcpu;
OpenPOWER on IntegriCloud
diff --git a/sys/amd64/include/pcpu.h b/sys/amd64/include/pcpu.h
index 9543b23..4055930 100644
--- a/sys/amd64/include/pcpu.h
+++ b/sys/amd64/include/pcpu.h
@@ -40,7 +40,8 @@
*/
#define PCPU_MD_FIELDS \
struct pcpu *pc_prvspace; /* Self-reference */ \
- register_t pc_scratch_rsp; /* User %rsp in syscall */
+ register_t pc_scratch_rsp; /* User %rsp in syscall */ \
+ u_int pc_acpi_id; /* ACPI CPU id */
#if defined(lint)